@@ -28,7 +28,7 @@
 #define XPATH_GET_FUNCTION "//Response/@function"
 #define XPATH_GET_ERRCODE "//Response[@class='systemMessages']/Params/string[@name='code']"
 
-#define LIB_PATH "libvkontakte.so"
+#define LIB_PATH "libmsavk.so"
 
 #define DRIVER_ID "vkontakte"
 #define NODE_SETTINGS "settings"
