@@ -23,7 +23,7 @@
  */
 guint sharing_plugin_interface_init (gboolean* dead_mans_switch)
 {
-    msa_print("%s:%d:%s: plugin initialization\n");
+    msa_print("%s:%d:%s: plugin initialization\n", __FILE__, __LINE__, __FUNCTION__);
     ULOG_DEBUG_L("sharing_manager_plugin_interface_init");
     return 0;
 }
@@ -38,7 +38,7 @@ guint sharing_plugin_interface_init (gboolean* dead_mans_switch)
  */
 guint sharing_plugin_interface_uninit (gboolean* dead_mans_switch)
 {
-    msa_print("%s:%d:%s: plugin shutdown\n");
+    msa_print("%s:%d:%s: plugin shutdown\n", __FILE__, __LINE__, __FUNCTION__);
     ULOG_DEBUG_L("sharing_manager_plugin_interface_uninit");
     return 0;
 }
@@ -156,14 +156,9 @@ sharing_plugin_interface_update_options (SharingAccount *account,
     gboolean ret = FALSE;
     GSList *list_albums = NULL;
 
-    const gchar* proxy_host = con_ic_connection_get_proxy_host(con,
-                        CON_IC_PROXY_PROTOCOL_HTTP);
-    gint proxy_port = con_ic_connection_get_proxy_port(con,
-                        CON_IC_PROXY_PROTOCOL_HTTP);
-
     gchar* account_name = sharing_account_get_username (account);
 
-    if(!libvk_init((gchar*) proxy_host, proxy_port, account_name)){
+    if(!libvk_init(con, account_name)){
         return SHARING_SEND_ERROR_UNKNOWN;
     }
 
