@@ -38,16 +38,16 @@ create_ui (GtkWindow* parent,
         dlg = gtk_dialog_new_with_buttons ("Account setup - Vkontakte", parent,
 				                           GTK_DIALOG_MODAL | GTK_DIALOG_DESTROY_WITH_PARENT,
 				                           "Use existing", 15,
-                                                           "Register new", 16,
+//                                                           "Register new", 16,
                                            NULL);
     }
 
     GtkWidget *dlg_content = gtk_dialog_get_content_area (GTK_DIALOG (dlg));
     GtkWidget* label1 = gtk_label_new("Use existing - use an existing vkontakte account");
-    GtkWidget* label2 = gtk_label_new("Register new - register new vkontakte account ");
+//    GtkWidget* label2 = gtk_label_new("Register new - register new vkontakte account ");
     GtkWidget* vbox = gtk_vbox_new(FALSE,0);
     gtk_box_pack_start(GTK_BOX(vbox), label1, FALSE, FALSE, 0);
-    gtk_box_pack_start(GTK_BOX(vbox), label2, FALSE, FALSE, 0);
+//    gtk_box_pack_start(GTK_BOX(vbox), label2, FALSE, FALSE, 0);
 
     /* User Name */
     GtkWidget *label3 = gtk_label_new ("Account name - this field is required.");
@@ -68,9 +68,9 @@ create_ui (GtkWindow* parent,
         sharing_account_set_param(account, NODE_SETTINGS, NULL);
         gtk_widget_destroy (dlg);
         return SHARING_EDIT_ACCOUNT_SUCCESS;
-    } else if (result == 16){
-        gtk_widget_destroy (dlg);
-        return SHARING_EDIT_ACCOUNT_SUCCESS;
+//    } else if (result == 16){
+//        gtk_widget_destroy (dlg);
+//        return SHARING_EDIT_ACCOUNT_SUCCESS;
     } else if (result == 17){
         gtk_widget_destroy (dlg);
         return SHARING_EDIT_ACCOUNT_DELETE;
